@@ -12,7 +12,7 @@ $EXCLUDES = []
   `dpkg-architecture -qDEB_HOST_ARCH`.strip,
 ].compact.each do |f|
   excludes = "debian/tests/exclude/#{f}"
-  if File.exists?(excludes)
+  if File.exist?(excludes)
     $EXCLUDES += File.read(excludes).split
   end
 end
